package com.auth.dao.base.mapper.v1;

import com.auth.dao.base.entity.PermissionEntity;
import com.auth.dao.base.entity.RoleEntity;
import com.auth.dao.base.entity.UserEntity;
import com.auth.dao.base.view.UserRolePermission;
import com.auth.model.base.dto.UserDto;
import com.auth.model.base.vo.UserVo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 用户信息 Mapper 接口
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:12:34
 */
@Mapper
public interface UserMapper extends BaseMapper<UserEntity> {

    /**
     * 分页查询用户信息内容
     *
     * @param pageParams 用户信息分页参数
     * @param dto        用户信息查询表单
     * @return 用户信息分页结果
     */
    IPage<UserVo> selectListByPage(@Param("page") Page<UserEntity> pageParams, @Param("dto") UserDto dto);

    /**
     * 根据用户id查询用户角色和权限信息
     *
     * @param userId 用户Id
     * @return 用户实体类
     */
    List<UserRolePermission> selectUserRolePermissionByUsername(Long userId);

    /**
     * 根据用户id查找该用户的角色内容
     *
     * @param userId 用户id
     * @return 当前用户的角色信息
     */
    List<RoleEntity> selectRolesByUserId(Long userId);

    /**
     * 根据用户id查找当前用户的权限
     *
     * @param userId 用户id
     * @return 权限列表
     */
    List<PermissionEntity> selectPermissionByUserId(Long userId);

    /**
     * 根据用户名查询用户信息
     *
     * @param username 用户名
     * @return 用户实体类
     */
    UserEntity selectByUsername(String username);
}
