package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.AuthLogEntity;
import com.auth.model.base.dto.AuthLogDto;
import com.auth.model.base.vo.AuthLogVo;
import com.auth.service.base.service.AuthLogService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统授权日志表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-20 12:42:00
 */
@Tag(name = "系统授权日志表", description = "系统授权日志表相关接口")
@RestController
@RequestMapping("/api/v1/base/auth-log")
@RequiredArgsConstructor
public class AuthLogController {

    private final AuthLogService authLogService;

    @Operation(summary = "分页查询系统授权日志表", description = "分页查询系统授权日志表")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<AuthLogVo>> getAuthLogPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            AuthLogDto dto) {
        Page<AuthLogEntity> pageParams = new Page<>(page, limit);
        PageResult<AuthLogVo> pageResult = authLogService.getAuthLogPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询系统授权日志表详情", description = "根据id查询系统授权日志表详情")
    @GetMapping("{id}")
    public Result<AuthLogVo> getAuthLogById(@PathVariable("id") Long id) {
        AuthLogVo authLogVo = authLogService.getAuthLogById(id);

        return Result.success(authLogVo);
    }

    @Operation(summary = "添加系统授权日志表", description = "添加系统授权日志表")
    @PostMapping()
    public Result<String> addAuthLog(@Valid @RequestBody AuthLogDto dto) {
        authLogService.addAuthLog(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新系统授权日志表", description = "更新系统授权日志表")
    @PutMapping()
    public Result<String> updateAuthLog(@Valid @RequestBody AuthLogDto dto) {
        authLogService.updateAuthLog(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除系统授权日志表", description = "删除系统授权日志表")
    @DeleteMapping()
    public Result<String> deleteAuthLog(@RequestBody List<Long> ids) {
        authLogService.deleteAuthLog(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }

}