package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.model.base.dto.FileDto;
import com.auth.model.base.vo.FileVo;
import com.auth.dao.base.entity.FileEntity;
import com.auth.service.base.service.FileService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统文件存储 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:06:38
 */
@Tag(name = "系统文件存储", description = "系统文件存储相关接口")
@RestController
@RequestMapping("/api/v1/base/file")
@RequiredArgsConstructor
public class FileController {

    private final FileService fileService;

    @Operation(summary = "分页查询系统文件存储", description = "分页查询系统文件存储")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<FileVo>> getFilePage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            FileDto dto) {
        Page<FileEntity> pageParams = new Page<>(page, limit);
        PageResult<FileVo> pageResult = fileService.getFilePage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询系统文件存储详情", description = "根据id查询系统文件存储详情")
    @GetMapping("{id}")
    public Result<FileVo> getFileById(@PathVariable("id") Long id) {
        FileVo fileVo = fileService.getFileById(id);

        return Result.success(fileVo);
    }

    @Operation(summary = "添加系统文件存储", description = "添加系统文件存储")
    @PostMapping()
    public Result<String> addFile(@Valid @RequestBody FileDto dto) {
        fileService.addFile(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新系统文件存储", description = "更新系统文件存储")
    @PutMapping()
    public Result<String> updateFile(@Valid @RequestBody FileDto dto) {
        fileService.updateFile(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除系统文件存储", description = "删除系统文件存储")
    @DeleteMapping()
    public Result<String> deleteFile(@RequestBody List<Long> ids) {
        fileService.deleteFile(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}