package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.model.base.dto.LoginLogDto;
import com.auth.model.base.vo.LoginLogVo;
import com.auth.dao.base.entity.LoginLogEntity;
import com.auth.service.base.service.LoginLogService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统用户登录日志 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:06:38
 */
@Tag(name = "系统用户登录日志", description = "系统用户登录日志相关接口")
@RestController
@RequestMapping("/api/v1/base/login-log")
@RequiredArgsConstructor
public class LoginLogController {

    private final LoginLogService loginLogService;

    @Operation(summary = "分页查询系统用户登录日志", description = "分页查询系统用户登录日志")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<LoginLogVo>> getLoginLogPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            LoginLogDto dto) {
        Page<LoginLogEntity> pageParams = new Page<>(page, limit);
        PageResult<LoginLogVo> pageResult = loginLogService.getLoginLogPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询系统用户登录日志详情", description = "根据id查询系统用户登录日志详情")
    @GetMapping("{id}")
    public Result<LoginLogVo> getLoginLogById(@PathVariable("id") Long id) {
        LoginLogVo loginLogVo = loginLogService.getLoginLogById(id);

        return Result.success(loginLogVo);
    }

    @Operation(summary = "添加系统用户登录日志", description = "添加系统用户登录日志")
    @PostMapping()
    public Result<String> addLoginLog(@Valid @RequestBody LoginLogDto dto) {
        loginLogService.addLoginLog(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新系统用户登录日志", description = "更新系统用户登录日志")
    @PutMapping()
    public Result<String> updateLoginLog(@Valid @RequestBody LoginLogDto dto) {
        loginLogService.updateLoginLog(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除系统用户登录日志", description = "删除系统用户登录日志")
    @DeleteMapping()
    public Result<String> deleteLoginLog(@RequestBody List<Long> ids) {
        loginLogService.deleteLoginLog(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}