package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.model.base.dto.MenuDto;
import com.auth.model.base.vo.MenuVo;
import com.auth.dao.base.entity.MenuEntity;
import com.auth.service.base.service.MenuService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统菜单权限 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:06:38
 */
@Tag(name = "系统菜单权限", description = "系统菜单权限相关接口")
@RestController
@RequestMapping("/api/v1/base/menu")
@RequiredArgsConstructor
public class MenuController {

    private final MenuService menuService;

    @Operation(summary = "分页查询系统菜单权限", description = "分页查询系统菜单权限")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<MenuVo>> getMenuPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            MenuDto dto) {
        Page<MenuEntity> pageParams = new Page<>(page, limit);
        PageResult<MenuVo> pageResult = menuService.getMenuPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询系统菜单权限详情", description = "根据id查询系统菜单权限详情")
    @GetMapping("{id}")
    public Result<MenuVo> getMenuById(@PathVariable("id") Long id) {
        MenuVo menuVo = menuService.getMenuById(id);

        return Result.success(menuVo);
    }

    @Operation(summary = "添加系统菜单权限", description = "添加系统菜单权限")
    @PostMapping()
    public Result<String> addMenu(@Valid @RequestBody MenuDto dto) {
        menuService.addMenu(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新系统菜单权限", description = "更新系统菜单权限")
    @PutMapping()
    public Result<String> updateMenu(@Valid @RequestBody MenuDto dto) {
        menuService.updateMenu(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除系统菜单权限", description = "删除系统菜单权限")
    @DeleteMapping()
    public Result<String> deleteMenu(@RequestBody List<Long> ids) {
        menuService.deleteMenu(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}