package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.model.base.dto.PermissionDto;
import com.auth.model.base.vo.PermissionVo;
import com.auth.dao.base.entity.PermissionEntity;
import com.auth.service.base.service.PermissionService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统权限表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:06:38
 */
@Tag(name = "系统权限表", description = "系统权限表相关接口")
@RestController
@RequestMapping("/api/v1/base/permission")
@RequiredArgsConstructor
public class PermissionController {

    private final PermissionService permissionService;

    @Operation(summary = "分页查询系统权限表", description = "分页查询系统权限表")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<PermissionVo>> getPermissionPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            PermissionDto dto) {
        Page<PermissionEntity> pageParams = new Page<>(page, limit);
        PageResult<PermissionVo> pageResult = permissionService.getPermissionPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询系统权限表详情", description = "根据id查询系统权限表详情")
    @GetMapping("{id}")
    public Result<PermissionVo> getPermissionById(@PathVariable("id") Long id) {
        PermissionVo permissionVo = permissionService.getPermissionById(id);

        return Result.success(permissionVo);
    }

    @Operation(summary = "添加系统权限表", description = "添加系统权限表")
    @PostMapping()
    public Result<String> addPermission(@Valid @RequestBody PermissionDto dto) {
        permissionService.addPermission(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新系统权限表", description = "更新系统权限表")
    @PutMapping()
    public Result<String> updatePermission(@Valid @RequestBody PermissionDto dto) {
        permissionService.updatePermission(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除系统权限表", description = "删除系统权限表")
    @DeleteMapping()
    public Result<String> deletePermission(@RequestBody List<Long> ids) {
        permissionService.deletePermission(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}