package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.model.base.dto.UserDeptDto;
import com.auth.model.base.vo.UserDeptVo;
import com.auth.dao.base.entity.UserDeptEntity;
import com.auth.service.base.service.UserDeptService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 部门用户关系表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-17 23:06:38
 */
@Tag(name = "部门用户关系表", description = "部门用户关系表相关接口")
@RestController
@RequestMapping("/api/v1/base/user-dept")
@RequiredArgsConstructor
public class UserDeptController {

    private final UserDeptService userDeptService;

    @Operation(summary = "分页查询部门用户关系表", description = "分页查询部门用户关系表")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<UserDeptVo>> getUserDeptPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            UserDeptDto dto) {
        Page<UserDeptEntity> pageParams = new Page<>(page, limit);
        PageResult<UserDeptVo> pageResult = userDeptService.getUserDeptPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "根据id查询部门用户关系表详情", description = "根据id查询部门用户关系表详情")
    @GetMapping("{id}")
    public Result<UserDeptVo> getUserDeptById(@PathVariable("id") Long id) {
        UserDeptVo userDeptVo = userDeptService.getUserDeptById(id);

        return Result.success(userDeptVo);
    }

    @Operation(summary = "添加部门用户关系表", description = "添加部门用户关系表")
    @PostMapping()
    public Result<String> addUserDept(@Valid @RequestBody UserDeptDto dto) {
        userDeptService.addUserDept(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新部门用户关系表", description = "更新部门用户关系表")
    @PutMapping()
    public Result<String> updateUserDept(@Valid @RequestBody UserDeptDto dto) {
        userDeptService.updateUserDept(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除部门用户关系表", description = "删除部门用户关系表")
    @DeleteMapping()
    public Result<String> deleteUserDept(@RequestBody List<Long> ids) {
        userDeptService.deleteUserDept(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}