package com.auth.service.base.service;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.EmailConfigDto;
import com.auth.model.base.vo.EmailConfigVo;
import com.auth.dao.base.entity.EmailConfigEntity;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * <p>
 * 系统邮件服务器配置 服务类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
public interface EmailConfigService extends IService<EmailConfigEntity> {

    /**
     * 分页查询系统邮件服务器配置
     *
     * @return 系统邮件服务器配置分页结果 {@link EmailConfigVo}
     */
    PageResult<EmailConfigVo> getEmailConfigPage(Page<EmailConfigEntity> pageParams, EmailConfigDto dto);

    /**
     * 根据id查询系统邮件服务器配置详情
     *
     * @param id 主键
     * @return 系统邮件服务器配置详情 EmailConfigVo}
     */
    EmailConfigVo getEmailConfigById(Long id);

    /**
     * 添加系统邮件服务器配置
     *
     * @param dto {@link EmailConfigDto} 添加表单
     */
    void addEmailConfig(EmailConfigDto dto);

    /**
     * 更新系统邮件服务器配置
     *
     * @param dto {@link EmailConfigDto} 更新表单
     */
    void updateEmailConfig(EmailConfigDto dto);

    /**
     * 删除|批量删除系统邮件服务器配置类型
     *
     * @param ids 删除id列表
     */
    void deleteEmailConfig(List<Long> ids);
}
