package com.auth.service.base.service;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.LoginLogDto;
import com.auth.model.base.vo.LoginLogVo;
import com.auth.dao.base.entity.LoginLogEntity;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * <p>
 * 系统用户登录日志 服务类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
public interface LoginLogService extends IService<LoginLogEntity> {

    /**
     * 分页查询系统用户登录日志
     *
     * @return 系统用户登录日志分页结果 {@link LoginLogVo}
     */
    PageResult<LoginLogVo> getLoginLogPage(Page<LoginLogEntity> pageParams, LoginLogDto dto);

    /**
     * 根据id查询系统用户登录日志详情
     *
     * @param id 主键
     * @return 系统用户登录日志详情 LoginLogVo}
     */
    LoginLogVo getLoginLogById(Long id);

    /**
     * 添加系统用户登录日志
     *
     * @param dto {@link LoginLogDto} 添加表单
     */
    void addLoginLog(LoginLogDto dto);

    /**
     * 更新系统用户登录日志
     *
     * @param dto {@link LoginLogDto} 更新表单
     */
    void updateLoginLog(LoginLogDto dto);

    /**
     * 删除|批量删除系统用户登录日志类型
     *
     * @param ids 删除id列表
     */
    void deleteLoginLog(List<Long> ids);
}
