package com.auth.service.base.service;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.UserDto;
import com.auth.model.base.vo.UserVo;
import com.auth.dao.base.entity.UserEntity;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * <p>
 * 用户信息 服务类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
public interface UserService extends IService<UserEntity> {

    /**
     * 分页查询用户信息
     *
     * @return 用户信息分页结果 {@link UserVo}
     */
    PageResult<UserVo> getUserPage(Page<UserEntity> pageParams, UserDto dto);

    /**
     * 根据id查询用户信息详情
     *
     * @param id 主键
     * @return 用户信息详情 UserVo}
     */
    UserVo getUserById(Long id);

    /**
     * 添加用户信息
     *
     * @param dto {@link UserDto} 添加表单
     */
    void addUser(UserDto dto);

    /**
     * 更新用户信息
     *
     * @param dto {@link UserDto} 更新表单
     */
    void updateUser(UserDto dto);

    /**
     * 删除|批量删除用户信息类型
     *
     * @param ids 删除id列表
     */
    void deleteUser(List<Long> ids);
}
