package com.auth.service.base.service.impl;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.DictDto;
import com.auth.model.base.vo.DictVo;
import com.auth.dao.base.entity.DictEntity;
import com.auth.dao.base.mapper.v1.DictMapper;
import com.auth.service.base.service.DictService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 系统数据字典 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
@Service
@Transactional
public class DictServiceImpl extends ServiceImpl<DictMapper, DictEntity> implements DictService {

    /**
     * 系统数据字典 服务实现类
     *
     * @param pageParams 系统数据字典分页查询page对象
     * @param dto        系统数据字典分页查询对象
     * @return 查询分页系统数据字典返回对象
     */
    @Override
    public PageResult<DictVo> getDictPage(Page<DictEntity> pageParams, DictDto dto) {
        IPage<DictVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<DictVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 根据id查询系统数据字典详情
     *
     * @param id 主键
     * @return 系统数据字典详情 DictVo}
     */
    public DictVo getDictById(Long id) {
        DictEntity dictEntity = getById(id);

        DictVo dictVo = new DictVo();
        BeanUtils.copyProperties(dictEntity, dictVo);

        return dictVo;
    }

    /**
     * 添加系统数据字典
     *
     * @param dto 系统数据字典添加
     */
    @Override
    public void addDict(DictDto dto) {
        DictEntity dict = new DictEntity();
        BeanUtils.copyProperties(dto, dict);

        save(dict);
    }

    /**
     * 更新系统数据字典
     *
     * @param dto 系统数据字典更新
     */
    @Override
    public void updateDict(DictDto dto) {
        DictEntity dict = new DictEntity();
        BeanUtils.copyProperties(dto, dict);

        updateById(dict);
    }

    /**
     * 删除|批量删除系统数据字典
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteDict(List<Long> ids) {
        removeByIds(ids);
    }
}