package com.auth.service.base.service.impl;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.FileDto;
import com.auth.model.base.vo.FileVo;
import com.auth.dao.base.entity.FileEntity;
import com.auth.dao.base.mapper.v1.FileMapper;
import com.auth.service.base.service.FileService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 系统文件存储 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
@Service
@Transactional
public class FileServiceImpl extends ServiceImpl<FileMapper, FileEntity> implements FileService {

    /**
     * 系统文件存储 服务实现类
     *
     * @param pageParams 系统文件存储分页查询page对象
     * @param dto        系统文件存储分页查询对象
     * @return 查询分页系统文件存储返回对象
     */
    @Override
    public PageResult<FileVo> getFilePage(Page<FileEntity> pageParams, FileDto dto) {
        IPage<FileVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<FileVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 根据id查询系统文件存储详情
     *
     * @param id 主键
     * @return 系统文件存储详情 FileVo}
     */
    public FileVo getFileById(Long id) {
        FileEntity fileEntity = getById(id);

        FileVo fileVo = new FileVo();
        BeanUtils.copyProperties(fileEntity, fileVo);

        return fileVo;
    }

    /**
     * 添加系统文件存储
     *
     * @param dto 系统文件存储添加
     */
    @Override
    public void addFile(FileDto dto) {
        FileEntity file = new FileEntity();
        BeanUtils.copyProperties(dto, file);

        save(file);
    }

    /**
     * 更新系统文件存储
     *
     * @param dto 系统文件存储更新
     */
    @Override
    public void updateFile(FileDto dto) {
        FileEntity file = new FileEntity();
        BeanUtils.copyProperties(dto, file);

        updateById(file);
    }

    /**
     * 删除|批量删除系统文件存储
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteFile(List<Long> ids) {
        removeByIds(ids);
    }
}