package com.auth.service.base.service.impl;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.LoginLogDto;
import com.auth.model.base.vo.LoginLogVo;
import com.auth.dao.base.entity.LoginLogEntity;
import com.auth.dao.base.mapper.v1.LoginLogMapper;
import com.auth.service.base.service.LoginLogService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 系统用户登录日志 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
@Service
@Transactional
public class LoginLogServiceImpl extends ServiceImpl<LoginLogMapper, LoginLogEntity> implements LoginLogService {

    /**
     * 系统用户登录日志 服务实现类
     *
     * @param pageParams 系统用户登录日志分页查询page对象
     * @param dto        系统用户登录日志分页查询对象
     * @return 查询分页系统用户登录日志返回对象
     */
    @Override
    public PageResult<LoginLogVo> getLoginLogPage(Page<LoginLogEntity> pageParams, LoginLogDto dto) {
        IPage<LoginLogVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<LoginLogVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 根据id查询系统用户登录日志详情
     *
     * @param id 主键
     * @return 系统用户登录日志详情 LoginLogVo}
     */
    public LoginLogVo getLoginLogById(Long id) {
        LoginLogEntity loginLogEntity = getById(id);

        LoginLogVo loginLogVo = new LoginLogVo();
        BeanUtils.copyProperties(loginLogEntity, loginLogVo);

        return loginLogVo;
    }

    /**
     * 添加系统用户登录日志
     *
     * @param dto 系统用户登录日志添加
     */
    @Override
    public void addLoginLog(LoginLogDto dto) {
        LoginLogEntity loginLog = new LoginLogEntity();
        BeanUtils.copyProperties(dto, loginLog);

        save(loginLog);
    }

    /**
     * 更新系统用户登录日志
     *
     * @param dto 系统用户登录日志更新
     */
    @Override
    public void updateLoginLog(LoginLogDto dto) {
        LoginLogEntity loginLog = new LoginLogEntity();
        BeanUtils.copyProperties(dto, loginLog);

        updateById(loginLog);
    }

    /**
     * 删除|批量删除系统用户登录日志
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteLoginLog(List<Long> ids) {
        removeByIds(ids);
    }
}