package com.auth.service.base.service.impl;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.RolePermissionDto;
import com.auth.model.base.vo.RolePermissionVo;
import com.auth.dao.base.entity.RolePermissionEntity;
import com.auth.dao.base.mapper.v1.RolePermissionMapper;
import com.auth.service.base.service.RolePermissionService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 系统角色权限表 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
@Service
@Transactional
public class RolePermissionServiceImpl extends ServiceImpl<RolePermissionMapper, RolePermissionEntity> implements RolePermissionService {

    /**
     * 系统角色权限表 服务实现类
     *
     * @param pageParams 系统角色权限表分页查询page对象
     * @param dto        系统角色权限表分页查询对象
     * @return 查询分页系统角色权限表返回对象
     */
    @Override
    public PageResult<RolePermissionVo> getRolePermissionPage(Page<RolePermissionEntity> pageParams, RolePermissionDto dto) {
        IPage<RolePermissionVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<RolePermissionVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 根据id查询系统角色权限表详情
     *
     * @param id 主键
     * @return 系统角色权限表详情 RolePermissionVo}
     */
    public RolePermissionVo getRolePermissionById(Long id) {
        RolePermissionEntity rolePermissionEntity = getById(id);

        RolePermissionVo rolePermissionVo = new RolePermissionVo();
        BeanUtils.copyProperties(rolePermissionEntity, rolePermissionVo);

        return rolePermissionVo;
    }

    /**
     * 添加系统角色权限表
     *
     * @param dto 系统角色权限表添加
     */
    @Override
    public void addRolePermission(RolePermissionDto dto) {
        RolePermissionEntity rolePermission = new RolePermissionEntity();
        BeanUtils.copyProperties(dto, rolePermission);

        save(rolePermission);
    }

    /**
     * 更新系统角色权限表
     *
     * @param dto 系统角色权限表更新
     */
    @Override
    public void updateRolePermission(RolePermissionDto dto) {
        RolePermissionEntity rolePermission = new RolePermissionEntity();
        BeanUtils.copyProperties(dto, rolePermission);

        updateById(rolePermission);
    }

    /**
     * 删除|批量删除系统角色权限表
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteRolePermission(List<Long> ids) {
        removeByIds(ids);
    }
}