package com.auth.service.base.service.impl;

import com.auth.common.model.common.result.PageResult;
import com.auth.model.base.dto.UserRoleDto;
import com.auth.model.base.vo.UserRoleVo;
import com.auth.dao.base.entity.UserRoleEntity;
import com.auth.dao.base.mapper.v1.UserRoleMapper;
import com.auth.service.base.service.UserRoleService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 系统用户角色关系表 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-17 23:06:38
 */
@Service
@Transactional
public class UserRoleServiceImpl extends ServiceImpl<UserRoleMapper, UserRoleEntity> implements UserRoleService {

    /**
     * 系统用户角色关系表 服务实现类
     *
     * @param pageParams 系统用户角色关系表分页查询page对象
     * @param dto        系统用户角色关系表分页查询对象
     * @return 查询分页系统用户角色关系表返回对象
     */
    @Override
    public PageResult<UserRoleVo> getUserRolePage(Page<UserRoleEntity> pageParams, UserRoleDto dto) {
        IPage<UserRoleVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<UserRoleVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 根据id查询系统用户角色关系表详情
     *
     * @param id 主键
     * @return 系统用户角色关系表详情 UserRoleVo}
     */
    public UserRoleVo getUserRoleById(Long id) {
        UserRoleEntity userRoleEntity = getById(id);

        UserRoleVo userRoleVo = new UserRoleVo();
        BeanUtils.copyProperties(userRoleEntity, userRoleVo);

        return userRoleVo;
    }

    /**
     * 添加系统用户角色关系表
     *
     * @param dto 系统用户角色关系表添加
     */
    @Override
    public void addUserRole(UserRoleDto dto) {
        UserRoleEntity userRole = new UserRoleEntity();
        BeanUtils.copyProperties(dto, userRole);

        save(userRole);
    }

    /**
     * 更新系统用户角色关系表
     *
     * @param dto 系统用户角色关系表更新
     */
    @Override
    public void updateUserRole(UserRoleDto dto) {
        UserRoleEntity userRole = new UserRoleEntity();
        BeanUtils.copyProperties(dto, userRole);

        updateById(userRole);
    }

    /**
     * 删除|批量删除系统用户角色关系表
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteUserRole(List<Long> ids) {
        removeByIds(ids);
    }
}